pub struct TryFromStringKeyError;Expand description
Error that may occur when converting a StringKey to some other Rust value, such as an integer or a string.
When converting to an integer, this means that the StringKey is a named key, or it has a numeric value that is out of range for the target type.
When converting to a string, this does not happen, as numeric keys will be converted to strings.